@@ -1,5 +1,6 @@
 from flask import current_app
 from flask_script import Command, Option
+from manhattan.publishing import PublishableFrame
 from mongoframes import Frame
 
 __all__ = ['add_command']
@@ -10,15 +11,36 @@ class BuildIndexes(Command):
     Find and (re)build indexes defined against models.
     """
 
-    def run(self):
+    def get_options(self):
+        return [
+            Option('--collection', '-c', dest='collection', default='all')
+        ]
+
+    def run(self, collection):
         for frame in self.find_frames():
+
+            # If a collection has been named skip all other collections
+            if collection not in ['all', frame.__name__]:
+                continue
+
             print('Building indexes for', frame.__name__)
 
-            # Drop any existing indexes
-            frame.get_collection().drop_indexes()
+            if issubclass(frame, PublishableFrame):
 
-            # Build indexes
-            frame.get_collection().create_indexes(frame._indexes)
+                # Rebuild the indexes
+
+                with frame._context_manager.draft():
+                    frame.get_collection().drop_indexes()
+                    frame.get_collection().create_indexes(frame._indexes)
+
+                with frame._context_manager.published():
+                    frame.get_collection().drop_indexes()
+                    frame.get_collection().create_indexes(frame._indexes)
+
+            else:
+                # Rebuild the indexes
+                frame.get_collection().drop_indexes()
+                frame.get_collection().create_indexes(frame._indexes)
 
         print('Indexes built')
 
