@@ -1,13 +1,15 @@
 from collections import namedtuple
 
 from .add import add_chains
+from .change_log import change_log_chains
 from .delete import delete_chains
 from .list import list_chains
 from .order import order_chains
 from .typeahead import typeahead_chains
 from .update import update_chains
 from .view import view_chains
-from .assets.gallery import gallery_chains
+
+from .related.list import related_list_chains
 
 __all__ = ['generic']
 
@@ -35,23 +37,29 @@ Generic = namedtuple(
     'Generic',
     [
         'add',
+        'change_log',
         'delete',
-        'gallery',
         'list',
         'order',
         'typeahead',
         'update',
-        'view'
+        'view',
+
+        # Related
+        'related_list'
     ])
 
 # Create an instance of Generic containing all the generic views
 generic = Generic(
     add=add_chains,
+    change_log=change_log_chains,
     delete=delete_chains,
-    gallery=gallery_chains,
     list=list_chains,
     order=order_chains,
     typeahead=typeahead_chains,
     update=update_chains,
-    view=view_chains
-    )
+    view=view_chains,
+
+    # Related
+    related_list=related_list_chains
+)
